# This file is generated by objective.metadata
#
# Last update: Sun Jul 11 21:38:13 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a


else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$FIMenuKindContextualMenuForContainer@1$FIMenuKindContextualMenuForItems@0$FIMenuKindContextualMenuForSidebar@2$FIMenuKindToolbarItemMenu@3$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"FIFinderSyncController", b"isExtensionEnabled", {"retval": {"type": "Z"}})
    r(
        b"FIFinderSyncController",
        b"setLastUsedDate:forItemWithURL:completion:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"FIFinderSyncController",
        b"setTagData:forItemWithURL:completion:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"NSObject",
        b"beginObservingDirectoryAtURL:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"endObservingDirectoryAtURL:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"makeListenerEndpointForServiceName:itemURL:andReturnError:",
        {
            "required": False,
            "retval": {"type": b"@"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": "^@", "type_modifier": b"o"},
            },
        },
    )
    r(
        b"NSObject",
        b"menuForMenuKind:",
        {"required": False, "retval": {"type": b"@"}, "arguments": {2: {"type": b"Q"}}},
    )
    r(
        b"NSObject",
        b"requestBadgeIdentifierForURL:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"supportedServiceNamesForItemWithURL:",
        {"required": False, "retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"toolbarItemImage", {"required": False, "retval": {"type": b"@"}})
    r(b"NSObject", b"toolbarItemName", {"required": False, "retval": {"type": b"@"}})
    r(b"NSObject", b"toolbarItemToolTip", {"required": False, "retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"valuesForAttributes:forItemWithURL:completion:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    },
                    "type": "@?",
                },
            },
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import FinderSync


class TestFinderSyncHelper(FinderSync.NSObject):
    def valuesForAttributes_forItemWithURL_completion_(self, at, iu, com):
        pass

    def makeListenerEndpointForServiceName_itemURL_andReturnError_(self, a, b, c):
        pass


class TestFinderSync(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(FinderSync.FIFinderSyncController, objc.objc_class)
        self.assertIsInstance(FinderSync.FIFinderSync, objc.objc_class)

    @min_os_level("10.10")
    def testProtocols(self):
        self.assertIsInstance(objc.protocolNamed("FIFinderSync"), objc.formal_protocol)

        self.assertArgIsBlock(
            TestFinderSyncHelper.valuesForAttributes_forItemWithURL_completion_,
            2,
            b"v@@",
        )

        self.assertArgIsOut(
            TestFinderSyncHelper.makeListenerEndpointForServiceName_itemURL_andReturnError_,
            2,
        )

    @min_os_level("10.10")
    def testConstants(self):
        self.assertEqual(FinderSync.FIMenuKindContextualMenuForItems, 0)
        self.assertEqual(FinderSync.FIMenuKindContextualMenuForContainer, 1)
        self.assertEqual(FinderSync.FIMenuKindContextualMenuForSidebar, 2)
        self.assertEqual(FinderSync.FIMenuKindToolbarItemMenu, 3)

    @min_os_level("10.13")
    def testMethods(self):
        self.assertArgIsBlock(
            FinderSync.FIFinderSyncController.setLastUsedDate_forItemWithURL_completion_,
            2,
            b"v@",
        )
        self.assertArgIsBlock(
            FinderSync.FIFinderSyncController.setTagData_forItemWithURL_completion_,
            2,
            b"v@",
        )

    @min_os_level("10.14")
    def testMethods10_14(self):
        self.assertResultIsBOOL(FinderSync.FIFinderSyncController.isExtensionEnabled)
